@@ -172,7 +172,7 @@ def rds(ctx, bucket, key, password=None, profile=None):
         {'}'}
         $cert = Get-Item "cert:/localmachine/my/$($thumbprint)"
         $filename = $cert.privatekey.cspkeycontainerinfo.uniquekeycontainername
-        $root = "c:\programdata\microsoft\crypto\rsa\machinekeys"
+        $root = 'c:\programdata\microsoft\crypto\rsa\machinekeys'
         $p = [io.path]::combine($root, $filename)
         $rule = new-object security.accesscontrol.filesystemaccessrule 'NETWORK SERVICE', 'Read', allow
         if ([io.file]::exists($p)) {'{'}
@@ -180,7 +180,7 @@ def rds(ctx, bucket, key, password=None, profile=None):
             $acl.addaccessrule($rule)
             echo "modifying acl on $p"
             set-acl $p $acl
-        {'}'}                          
+        {'}'}
         """
     )
     print(c)
